@@ -519,7 +519,7 @@ def F_shuffle_dict_libraries(*args, **kwargs):
 #
 
 def resampling(data1, data2, S=10000, testFunc=F_mean_diff_flat,
-            permFunc=F_shuffle_flat, adaptive=False, lib_str1="", lib_str2=""):
+            permFunc=F_shuffle_flat, adaptive=False, lib_str1="", lib_str2="",PC=1):
     """Does a permutation test on two sets of data.
 
     Performs the resampling / permutation test given two sets of data using a
@@ -589,15 +589,11 @@ def resampling(data1, data2, S=10000, testFunc=F_mean_diff_flat,
     if n2 > 0:
         mean2 = numpy.mean(data2)
 
-    try:
-        # Only adjust log2FC if one of the means is zero
-        if mean1 > 0 and mean2 > 0:
-            log2FC = math.log((mean2)/(mean1),2)
-        else:
-            log2FC = math.log((mean2+1.0)/(mean1+1.0),2)
-    except:
-        log2FC = 0.0
-   
+    if PC>0: log2FC = math.log((mean2+PC)/(mean1+PC),2) # as of 3/5/20
+    else:
+      # Only adjust log2FC if one of the means is zero
+      if mean1 > 0 and mean2 > 0: log2FC = math.log((mean2)/(mean1),2)
+      else: log2FC = math.log((mean2+1.0)/(mean1+1.0),2)
 
  
     # Get stats and info based on whether working with libraries or not:
